@@ -85,6 +85,7 @@ struct _AsyncContext {
 	gchar *folder_uri;
 	gchar *message_uid;
 	gboolean replace;
+	GtkWidget *destroy_when_done;
 };
 
 struct _ForwardData {
@@ -112,6 +113,9 @@ async_context_free (AsyncContext *context)
 	if (context->ptr_array != NULL)
 		g_ptr_array_unref (context->ptr_array);
 
+	if (context->destroy_when_done != NULL)
+		gtk_widget_destroy (context->destroy_when_done);
+
 	g_free (context->folder_uri);
 	g_free (context->message_uid);
 
@@ -179,10 +183,10 @@ ask_confirm_for_only_bcc (EMsgComposer *composer,
                           gboolean hidden_list_case)
 {
 	/* If the user is mailing a hidden contact list, it is possible for
-	   them to create a message with only Bcc recipients without really
-	   realizing it.  To try to avoid being totally confusing, I've changed
-	   this dialog to provide slightly different text in that case, to
-	   better explain what the hell is going on. */
+	 * them to create a message with only Bcc recipients without really
+	 * realizing it.  To try to avoid being totally confusing, I've changed
+	 * this dialog to provide slightly different text in that case, to
+	 * better explain what the hell is going on. */
 
 	return em_utils_prompt_user (
 		GTK_WINDOW (composer),
@@ -1028,7 +1032,9 @@ em_utils_compose_new_message_with_mailto (EShell *shell,
 }
 
 static gboolean
-replace_variables (GSList *clues, CamelMimeMessage *message, gchar **pstr)
+replace_variables (GSList *clues,
+                   CamelMimeMessage *message,
+                   gchar **pstr)
 {
 	gint i;
 	gboolean string_changed = FALSE, count1 = FALSE;
@@ -1057,7 +1063,7 @@ replace_variables (GSList *clues, CamelMimeMessage *message, gchar **pstr)
 
 			for (list = clues; list; list = g_slist_next (list)) {
 				gchar **temp = g_strsplit (list->data, "=", 2);
-				if (!g_ascii_strcasecmp (temp[0], out+1)) {
+				if (!g_ascii_strcasecmp (temp[0], out + 1)) {
 					g_free (str);
 					str = g_strconcat (temp_str[0], temp[1], temp_str[1], NULL);
 					count1 = TRUE;
@@ -1068,7 +1074,7 @@ replace_variables (GSList *clues, CamelMimeMessage *message, gchar **pstr)
 			}
 
 			if (!count1) {
-				if (getenv (out+1)) {
+				if (getenv (out + 1)) {
 					g_free (str);
 					str = g_strconcat (
 						temp_str[0],
@@ -1113,7 +1119,9 @@ replace_variables (GSList *clues, CamelMimeMessage *message, gchar **pstr)
 }
 
 static void
-traverse_parts (GSList *clues, CamelMimeMessage *message, CamelDataWrapper *content)
+traverse_parts (GSList *clues,
+                CamelMimeMessage *message,
+                CamelDataWrapper *content)
 {
 	g_return_if_fail (message != NULL);
 
@@ -1401,7 +1409,8 @@ em_utils_edit_messages (EMailReader *reader,
 }
 
 static void
-emu_update_composers_security (EMsgComposer *composer, guint32 validity_found)
+emu_update_composers_security (EMsgComposer *composer,
+                               guint32 validity_found)
 {
 	GtkToggleAction *action;
 
@@ -1426,7 +1435,8 @@ emu_update_composers_security (EMsgComposer *composer, guint32 validity_found)
 }
 
 static void
-real_update_forwarded_flag (gpointer uid, gpointer folder)
+real_update_forwarded_flag (gpointer uid,
+                            gpointer folder)
 {
 	if (uid && folder)
 		camel_folder_set_message_flags (
@@ -1674,6 +1684,7 @@ forward_got_messages_cb (CamelFolder *folder,
 
 	if (e_activity_handle_cancellation (context->activity, error)) {
 		g_warn_if_fail (hash_table == NULL);
+		context->destroy_when_done = NULL;
 		async_context_free (context);
 		g_error_free (error);
 		return;
@@ -1684,6 +1695,7 @@ forward_got_messages_cb (CamelFolder *folder,
 			alert_sink,
 			"mail:get-multiple-messages",
 			error->message, NULL);
+		context->destroy_when_done = NULL;
 		async_context_free (context);
 		g_error_free (error);
 		return;
@@ -1715,6 +1727,7 @@ forward_got_messages_cb (CamelFolder *folder,
  * @folder: folder containing messages to forward
  * @uids: uids of messages to forward
  * @style: the forward style to use
+ * @destroy_when_done: a #GtkWidget to destroy with gtk_widget_destroy() when done; can be NULL
  *
  * Forwards a group of messages in the given style.
  *
@@ -1736,7 +1749,8 @@ void
 em_utils_forward_messages (EMailReader *reader,
                            CamelFolder *folder,
                            GPtrArray *uids,
-                           EMailForwardStyle style)
+                           EMailForwardStyle style,
+			   GtkWidget *destroy_when_done)
 {
 	EActivity *activity;
 	AsyncContext *context;
@@ -1754,6 +1768,7 @@ em_utils_forward_messages (EMailReader *reader,
 	context->reader = g_object_ref (reader);
 	context->ptr_array = g_ptr_array_ref (uids);
 	context->style = style;
+	context->destroy_when_done = destroy_when_done;
 
 	switch (style) {
 		case E_MAIL_FORWARD_STYLE_ATTACHED:
@@ -1782,27 +1797,27 @@ static EMsgComposer *
 redirect_get_composer (EShell *shell,
                        CamelMimeMessage *message)
 {
-	EMsgComposer *composer;
+	CamelMedium *medium;
 	EAccount *account;
 
+	medium = CAMEL_MEDIUM (message);
+
 	/* QMail will refuse to send a message if it finds one of
-	   it's Delivered-To headers in the message, so remove all
-	   Delivered-To headers. Fixes bug #23635. */
-	while (camel_medium_get_header (CAMEL_MEDIUM (message), "Delivered-To"))
-		camel_medium_remove_header (CAMEL_MEDIUM (message), "Delivered-To");
+	 * it's Delivered-To headers in the message, so remove all
+	 * Delivered-To headers. Fixes bug #23635. */
+	while (camel_medium_get_header (medium, "Delivered-To"))
+		camel_medium_remove_header (medium, "Delivered-To");
 
-	while (camel_medium_get_header (CAMEL_MEDIUM (message), "Bcc"))
-		camel_medium_remove_header (CAMEL_MEDIUM (message), "Bcc");
+	while (camel_medium_get_header (medium, "Bcc"))
+		camel_medium_remove_header (medium, "Bcc");
 
-	while (camel_medium_get_header (CAMEL_MEDIUM (message), "Resent-Bcc"))
-		camel_medium_remove_header (CAMEL_MEDIUM (message), "Resent-Bcc");
+	while (camel_medium_get_header (medium, "Resent-Bcc"))
+		camel_medium_remove_header (medium, "Resent-Bcc");
 
 	account = em_utils_guess_account_with_recipients (message, NULL);
 
-	composer = e_msg_composer_new_redirect (
+	return e_msg_composer_new_redirect (
 		shell, message, account ? account->name : NULL, NULL);
-
-	return composer;
 }
 
 /**
@@ -1967,9 +1982,10 @@ em_utils_send_receipt (EMailSession *session,
 		message_date ="";
 
 	/* Create toplevel container */
-	camel_data_wrapper_set_mime_type (CAMEL_DATA_WRAPPER (body),
-					  "multipart/report;"
-					  "report-type=\"disposition-notification\"");
+	camel_data_wrapper_set_mime_type (
+		CAMEL_DATA_WRAPPER (body),
+		"multipart/report;"
+		"report-type=\"disposition-notification\"");
 	camel_multipart_set_boundary (body, NULL);
 
 	/* Create textual receipt */
@@ -2036,7 +2052,8 @@ em_utils_send_receipt (EMailSession *session,
 	g_object_unref (part);
 
 	/* Finish creating the message */
-	camel_medium_set_content (CAMEL_MEDIUM (receipt), CAMEL_DATA_WRAPPER (body));
+	camel_medium_set_content (
+		CAMEL_MEDIUM (receipt), CAMEL_DATA_WRAPPER (body));
 	g_object_unref (body);
 
 	/* Translators: %s is the subject of the email message */
@@ -2052,7 +2069,8 @@ em_utils_send_receipt (EMailSession *session,
 
 	addr = camel_internet_address_new ();
 	camel_address_decode (CAMEL_ADDRESS (addr), receipt_address);
-	camel_mime_message_set_recipients (receipt, CAMEL_RECIPIENT_TYPE_TO, addr);
+	camel_mime_message_set_recipients (
+		receipt, CAMEL_RECIPIENT_TYPE_TO, addr);
 	g_object_unref (addr);
 
 	transport_uid = g_strconcat (account->uid, "-transport", NULL);
@@ -2139,12 +2157,17 @@ reply_get_composer (EShell *shell,
 	EDestination **tov, **ccv;
 	EMsgComposer *composer;
 	EComposerHeaderTable *table;
+	CamelMedium *medium;
 	gchar *subject;
 
 	g_return_val_if_fail (E_IS_SHELL (shell), NULL);
 	g_return_val_if_fail (CAMEL_IS_MIME_MESSAGE (message), NULL);
-	g_return_val_if_fail (to == NULL || CAMEL_IS_INTERNET_ADDRESS (to), NULL);
-	g_return_val_if_fail (cc == NULL || CAMEL_IS_INTERNET_ADDRESS (cc), NULL);
+
+	if (to != NULL)
+		g_return_val_if_fail (CAMEL_IS_INTERNET_ADDRESS (to), NULL);
+
+	if (cc != NULL)
+		g_return_val_if_fail (CAMEL_IS_INTERNET_ADDRESS (cc), NULL);
 
 	composer = e_msg_composer_new (shell);
 
@@ -2196,7 +2219,7 @@ reply_get_composer (EShell *shell,
 			store_url = camel_url_to_string (
 				url, CAMEL_URL_HIDE_ALL);
 			if (store_url[strlen (store_url) - 1] == '/')
-				store_url[strlen (store_url)-1] = '\0';
+				store_url[strlen (store_url) - 1] = '\0';
 		}
 
 		post = camel_address_encode ((CamelAddress *) postto);
@@ -2207,29 +2230,38 @@ reply_get_composer (EShell *shell,
 	}
 
 	/* Add In-Reply-To and References. */
-	message_id = camel_medium_get_header (CAMEL_MEDIUM (message), "Message-ID");
-	references = camel_medium_get_header (CAMEL_MEDIUM (message), "References");
-	if (message_id) {
+
+	medium = CAMEL_MEDIUM (message);
+	message_id = camel_medium_get_header (medium, "Message-ID");
+	references = camel_medium_get_header (medium, "References");
+
+	if (message_id != NULL) {
 		gchar *reply_refs;
 
-		e_msg_composer_add_header (composer, "In-Reply-To", message_id);
+		e_msg_composer_add_header (
+			composer, "In-Reply-To", message_id);
 
 		if (references)
-			reply_refs = g_strdup_printf ("%s %s", references, message_id);
+			reply_refs = g_strdup_printf (
+				"%s %s", references, message_id);
 		else
 			reply_refs = g_strdup (message_id);
 
-		e_msg_composer_add_header (composer, "References", reply_refs);
+		e_msg_composer_add_header (
+			composer, "References", reply_refs);
 		g_free (reply_refs);
-	} else if (references) {
-		e_msg_composer_add_header (composer, "References", references);
+
+	} else if (references != NULL) {
+		e_msg_composer_add_header (
+			composer, "References", references);
 	}
 
 	return composer;
 }
 
 static gboolean
-get_reply_list (CamelMimeMessage *message, CamelInternetAddress *to)
+get_reply_list (CamelMimeMessage *message,
+                CamelInternetAddress *to)
 {
 	const gchar *header, *p;
 	gchar *addr;
@@ -2555,7 +2587,9 @@ typedef void		(*AttribFormatter)	(GString *str,
 						 CamelMimeMessage *message);
 
 static void
-format_sender (GString *str, const gchar *attr, CamelMimeMessage *message)
+format_sender (GString *str,
+               const gchar *attr,
+               CamelMimeMessage *message)
 {
 	CamelInternetAddress *sender;
 	const gchar *name, *addr = NULL;
@@ -2805,8 +2839,8 @@ composer_set_body (EMsgComposer *composer,
 		const gchar *key;
 
 		/* If we are placing signature on top, then move cursor to the end,
-		   otherwise try to find the signature place and place cursor just
-		   before the signature. We added there an empty line already. */
+		 * otherwise try to find the signature place and place cursor just
+		 * before the signature. We added there an empty line already. */
 		gtkhtml_editor_run_command (editor, "block-selection");
 		gtkhtml_editor_run_command (editor, "cursor-bod");
 
@@ -2828,7 +2862,8 @@ composer_set_body (EMsgComposer *composer,
 }
 
 gchar *
-em_utils_construct_composer_text (CamelMimeMessage *message, EMFormat *source)
+em_utils_construct_composer_text (CamelMimeMessage *message,
+                                  EMFormat *source)
 {
 	gchar *text, *credits;
 	gboolean start_bottom = 0;
@@ -2865,8 +2900,8 @@ em_utils_reply_to_message (EShell *shell,
                            const gchar *message_uid,
                            EMailReplyType type,
                            EMailReplyStyle style,
-                           EMFormat *source,
-			   CamelInternetAddress *address)
+                           EMFormat *source_formatter,
+                           CamelInternetAddress *address)
 {
 	CamelInternetAddress *to, *cc;
 	CamelNNTPAddress *postto = NULL;
@@ -2925,7 +2960,7 @@ em_utils_reply_to_message (EShell *shell,
 	g_object_unref (to);
 	g_object_unref (cc);
 
-	composer_set_body (composer, message, style, source);
+	composer_set_body (composer, message, style, source_formatter);
 
 	if (folder != NULL) {
 		gchar *folder_uri;
